function [est]=peakmaker(m);

%*******************************************************************
%
% function peakmaker by J.M. Daz-Cruz, February 2001
%                                       Last Revised October 2007
%
% From an initial view of the data matrix (m), it makes an initial 
% estimate (est) of peak-shaped signals or concentrations according 
% to a gaussian function (symmetric peak) or two gaussian functions
% (asymmetric peak). In m matrix, potentials must be in rows.
% The steps to follow are:
%
% - Click by order with mouse at the position of the maximum of the 
%   peak of every desired component. When all peaks have been defined,
%   press enter
% - The program draws the gaussian peaks with the desired position and
%   height but with a default width.
% - One by one, the program shows every active peak in red colour 
%   with a horizontal line at the middle of the height. Then, click 
%   with mouse at the x-position where you want the peak to cross
%   the line at half height. When symmetrical peaks are selected, only 
%   one click is required at any side of the maximum. In the case of
%   asymmetrical peaks, clicking at the left and right sides of the 
%   maximum defines the two different widths.
%
% Syntax:   [est]=peakmaker(m); 
%
%********************************************************************

disp(' ');disp('INITIAL ESTIMATION OF PEAK-SHAPED FUNCTIONS');disp(' ');
isym=input('Symmetric peak? yes (1), no (0)   ');disp(' ');
disp('Select maxima of the peaks');disp('with mouse and press enter');disp(' ');

[nrows,ncol]=size(m);

%arbitrary x-axis
x=1;
for i=2:nrows;
   x=[x;i];
end

%plot of the matrix and graphical input of the peaks
plot(x,m,'c');
[x0,y0]=ginput;
[npeaks,ans]=size(x0);

%default value for width
s=10;

%initial plot of the gaussian peaks
for n=1:npeaks;
   est(:,n)=y0(n).*exp(-(x-x0(n)).^2./s);
end;
plot(x,m,'g',x,est,'r');

disp('Select half peak width with mouse');

%graphical input of the width
if isym==1, %symmetric peaks
   for n=1:npeaks;
   plot(x,m,'c',x,est,'k',x,est(:,n),'ro',x,est(:,n),'r',x,y0(n)./2*ones(1,nrows),'r');
   [x1,y1]=ginput(1);
   s=1/log(2)*(x1-x0(n))^2;
   est(:,n)=y0(n).*exp(-(x-x0(n)).^2./s);
   plot(x,m,'c',x,est,'k');   
   end;
else       %asymmetric peaks
   for n=1:npeaks;
   plot(x,m,'c',x,est,'k',x,est(:,n),'ro',x,est(:,n),'r',x,y0(n)./2*ones(1,nrows),'r');
   [x1,y1]=ginput(1);
   [x2,y2]=ginput(1);
   s1=1/log(2)*(x1-x0(n))^2;
   s2=1/log(2)*(x2-x0(n))^2;
   if x1<x2
      for i=1:nrows,
         if x(i)<=x0(n);est(i,n)=y0(n).*exp(-(x(i)-x0(n)).^2./s1);
         else est(i,n)=y0(n).*exp(-(x(i)-x0(n)).^2./s2);
         end
      end 
   else
      for i=1:nrows,
         if x(i)<=x0(n);est(i,n)=y0(n).*exp(-(x(i)-x0(n)).^2./s2);
         else est(i,n)=y0(n).*exp(-(x(i)-x0(n)).^2./s1);
         end
      end 
   end
   
   plot(x,m,'c',x,est,'k');   
   
   end;
end

%final plot
plot(x,est);
   

